==> haskell-tasty-th-0.1.7-648.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-th
version:              0.1.7
visibility:           public
id:                   tasty-th-0.1.7-Bg67o2kT5978NftvwwDHxe
key:                  tasty-th-0.1.7-Bg67o2kT5978NftvwwDHxe
license:              BSD-3-Clause
maintainer:           Benno Fünfstück <benno.fuenfstueck@gmail.com>
author:               Oscar Finnsson & Emil Nordling & Benno Fünfstück
homepage:             http://github.com/bennofs/tasty-th
synopsis:             Automatic tasty test case discovery using TH
description:
    Generate tasty TestTrees automatically with TemplateHaskell. See the README for example usage.

category:             Testing
abi:                  282155a1580191b49385a9b8ce8162d5
exposed:              True
exposed-modules:      Test.Tasty.TH
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-th-0.1.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-th-0.1.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-th-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-th
hs-libraries:         HStasty-th-0.1.7-Bg67o2kT5978NftvwwDHxe
depends:
    base-4.18.2.1 haskell-src-exts-1.23.1-F3jL8MeOgpf1H3BDGTEVcV
    tasty-1.5.2-K3PchMZYxV2JdxeMIpuhjP template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-tasty-th/html/tasty-th.haddock
haddock-html:         /usr/share/doc/haskell-tasty-th/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-th-0.1.7-654-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-th
version:              0.1.7
visibility:           public
id:                   tasty-th-0.1.7-pw43h3eQg6I1XOjYAp8yt
key:                  tasty-th-0.1.7-pw43h3eQg6I1XOjYAp8yt
license:              BSD-3-Clause
maintainer:           Benno Fünfstück <benno.fuenfstueck@gmail.com>
author:               Oscar Finnsson & Emil Nordling & Benno Fünfstück
homepage:             http://github.com/bennofs/tasty-th
synopsis:             Automatic tasty test case discovery using TH
description:
    Generate tasty TestTrees automatically with TemplateHaskell. See the README for example usage.

category:             Testing
abi:                  3354899ddc4e695870d2a042f31c3bc2
exposed:              True
exposed-modules:      Test.Tasty.TH
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-th-0.1.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-th-0.1.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-th-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-th
hs-libraries:         HStasty-th-0.1.7-pw43h3eQg6I1XOjYAp8yt
depends:
    base-4.18.2.1 haskell-src-exts-1.23.1-63590nDmfj1880iQCS4JdS
    tasty-1.5.2-C3yI3pzTEHWEDVqwlNW4dB template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-tasty-th/html/tasty-th.haddock
haddock-html:         /usr/share/doc/haskell-tasty-th/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
